## ClimetLab-Intake

* Source plugin added
* Tests added
* Dataset plugin with cookiecutter guidelines added, repo: https://github.com/esowc/climetlab-intake-data

TODO:

* matplotlib driver addition along with magics (high priority)
* Caching mechanism with fsspec and https://github.com/ecmwf/climetlab/blob/master/climetlab/core/caching.py (low priority)
